Tools
=====
This directory contains tools for use with the ``pymongo`` module.

validate and validate.py
========================
These scripts are used by 10gen's driver testing tools to verify the
correctness of ``pymongo`` BSON module (``pymongo.bson``).

driver_tests.py
===============
This script is used by 10gen's
`driver testing framework. <http://mongodb.onconfluence.com/display/DOCS/Mongo+Driver+Test+Framework>`_
